import{e as n,ab as r}from"./index-Cc0s9xHj.js";import{d as m,c as o,ae as i,u as c,h as l,b as d}from"./lucide-C_a_D9Y7.js";import{z as s}from"./external-DYYiymTi.js";const w=m({__name:"FieldDescription",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e;return(t,p)=>(d(),o("p",{"data-slot":"field-description",class:i(c(n)("text-muted-foreground text-sm leading-normal font-normal group-has-[[data-orientation=horizontal]]/field:text-balance","last:mt-0 nth-last-2:-mt-1 [[data-variant=legend]+&]:-mt-1.5","[&>a:hover]:text-primary [&>a]:underline [&>a]:underline-offset-4",a.class))},[l(t.$slots,"default")],2))}}),_=e=>s.object({newPassword:s.string().max(128,"Password must be at most 128 characters."),confirmPassword:s.string()}).refine(a=>a.newPassword===a.confirmPassword,{message:e("auth.passwords_must_match"),path:["confirmPassword"]}),b=e=>s.object({username:s.string().min(2,e("auth.username_min_length")).max(50,"Username must be at most 50 characters."),displayName:s.string().max(100,"Display name must be at most 100 characters."),avatarUrl:s.string().refine(a=>!a||s.string().url().safeParse(a).success,{message:"Invalid URL format."}),role:s.string()}),u=e=>s.string().min(1,e("auth.field_required")).max(100,"Token name must be at most 100 characters."),P=e=>s.object({tokenName:u(e)}),x=e=>s.object({username:s.string().min(2,e("auth.username_min_length")).max(50,"Username must be at most 50 characters."),displayName:s.string().max(100,"Display name must be at most 100 characters."),password:s.string().min(8,e("auth.password_min_length")).max(128,"Password must be at most 128 characters."),confirmPassword:s.string(),role:s.enum(r),playerFilter:s.array(s.string()),providerFilter:s.array(s.string())}).refine(a=>a.password===a.confirmPassword,{message:e("auth.passwords_must_match"),path:["confirmPassword"]}),y=e=>s.object({username:s.string().min(2,e("auth.username_min_length")).max(50,"Username must be at most 50 characters."),displayName:s.string().max(100,"Display name must be at most 100 characters."),avatarUrl:s.string().refine(a=>!a||s.string().url().safeParse(a).success,{message:"Invalid URL format."}),role:s.enum(r),password:s.string().max(128,"Password must be at most 128 characters."),confirmPassword:s.string(),playerFilter:s.array(s.string()),providerFilter:s.array(s.string())}).refine(a=>!a.password||a.password===a.confirmPassword,{message:e("auth.passwords_must_match"),path:["confirmPassword"]});export{w as _,_ as a,x as b,P as c,y as e,b as p,u as t};
