import{e as r}from"./index-Cc0s9xHj.js";import{_ as o}from"./index-CT6dMj3N.js";import{i as n}from"./index-DYhKBjHd.js";import{d as i,G as l,u as s,ae as p,H as u,h as c,b as m}from"./lucide-C_a_D9Y7.js";const h=i({__name:"InputGroupButton",props:{variant:{default:"ghost"},size:{default:"xs"},class:{type:[Boolean,null,String,Object,Array]}},setup(t){const a=t;return(e,f)=>(m(),l(s(o),{"data-size":a.size,variant:a.variant,class:p(s(r)(s(n)({size:a.size}),a.class))},{default:u(()=>[c(e.$slots,"default")]),_:3},8,["data-size","variant","class"]))}});export{h as _};
