.now-playing-badge{background:rgb(var(--v-theme-primary));color:#fff;padding:2px 8px;border-radius:999px;font-size:.55rem;text-transform:uppercase;letter-spacing:.5px}.is-playing{font-weight:600}.now-playing-icon{display:flex;gap:2px;margin-left:6px;margin-right:6px;align-items:flex-end;height:16px}.now-playing-icon .bar{width:3px;height:16px;background:rgb(var(--v-theme-primary));transform-origin:bottom;transform:scaleY(.25);animation:eq 1s infinite ease-in-out;will-change:transform}.now-playing-icon .bar:nth-child(1){animation-delay:0s}.now-playing-icon .bar:nth-child(2){animation-delay:.2s}.now-playing-icon .bar:nth-child(3){animation-delay:.4s}.now-playing-icon .bar:nth-child(4){animation-delay:.6s}@keyframes eq{0%,to{transform:scaleY(.25)}50%{transform:scaleY(1)}}
