import{M as f}from"./index-kQIztB-E.js";import{g as r,d as y,Z as d,G as c,D as b,u as p,ar as m,O as B,H as u,h,K as g,b as v}from"./lucide-C_a_D9Y7.js";import{m as w,d as x}from"./vuetify-CvGbteJu.js";import{_ as k}from"./index-Cc0s9xHj.js";const C=(...t)=>t.filter(Boolean).join(" "),$=t=>{const l=r(()=>{const{variant:i,nav:a,...n}=t,e={...n,"aria-label":t.title||t["aria-label"]};return f(i).with("responsive",()=>({...e,icon:!0,variant:"text",ripple:t.ripple!==!1,class:t.class?`btn-responsive ${t.class}`:"btn-responsive",style:{height:"var(--responsive-button-size, min(calc(100vw - 40px), calc(100vh - 340px)))",width:"var(--responsive-button-size, min(calc(100vw - 40px), calc(100vh - 340px)))",...typeof t.style=="object"?t.style:{}}})).with("icon",()=>({...e,icon:!0,variant:"plain",ripple:t.ripple!==!1,class:t.class?`btn-icon ${t.class}`:"btn-icon"})).with("list",()=>({...e,variant:"plain",density:"comfortable",ripple:t.ripple!==!1,class:t.class?`btn-list ${t.class}`:"btn-list"})).with("plain",()=>({...e,variant:"plain",ripple:t.ripple!==!1})).with("default",()=>({...e,variant:"text",ripple:t.ripple!==!1})).otherwise(()=>({...e,variant:"text",ripple:t.ripple!==!1}))}),o=r(()=>C("button",t.variant&&`button--${t.variant}`,t.nav&&"button--nav"));return{buttonProps:l,buttonClasses:o}},P={variant:"default",ripple:!0},S=y({__name:"Button",props:d({variant:{},nav:{type:Boolean},icon:{type:[String,Boolean]},ripple:{type:Boolean},height:{},width:{},size:{},title:{},disabled:{type:Boolean},color:{},to:{},block:{type:Boolean},density:{},flat:{type:Boolean},loading:{type:Boolean},outlined:{type:Boolean},rounded:{type:[Boolean,String,Number]},tag:{},text:{type:Boolean},type:{},value:{},active:{type:Boolean},append:{type:Boolean},exact:{type:Boolean},replace:{type:Boolean},slim:{type:Boolean},stacked:{type:Boolean},class:{},style:{},"aria-label":{}},P),emits:["click"],setup(t){const l=t,{buttonProps:o,buttonClasses:i}=$(l);return(a,n)=>(v(),c(w,b(p(o),{class:p(i),onClick:n[0]||(n[0]=e=>a.$emit("click",e))}),m({default:u(()=>[t.icon&&typeof t.icon=="string"?(v(),c(x,{key:0,icon:t.icon},null,8,["icon"])):g("",!0)]),_:2},[B(a.$slots,(e,s)=>({name:s,fn:u(()=>[h(a.$slots,s,{},void 0,!0)])}))]),1040,["class"]))}}),D=k(S,[["__scopeId","data-v-f097a0e8"]]);export{D as M,C as m};
