import{_ as r}from"./reka-ui-jliV5UPF.js";import{e as l}from"./index-Cc0s9xHj.js";import{d as n,G as p,u as e,D as d,H as c,h as i,b as m}from"./lucide-C_a_D9Y7.js";import{l as u}from"./vueuse-Blk5jQ0T.js";const h=n({__name:"Label",props:{for:{},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(s){const a=s,t=u(a,"class");return(o,f)=>(m(),p(e(r),d({"data-slot":"label"},e(t),{class:e(l)("flex items-center gap-2 text-sm leading-none font-medium select-none group-data-[disabled=true]:pointer-events-none group-data-[disabled=true]:opacity-50 peer-disabled:cursor-not-allowed peer-disabled:opacity-50",a.class)}),{default:c(()=>[i(o.$slots,"default")]),_:3},16,["class"]))}});export{h as _};
