import{e as n}from"./index-Cc0s9xHj.js";import{d as o,G as r,ae as i,u as e,am as l,b as t}from"./lucide-C_a_D9Y7.js";const d=o({__name:"Spinner",props:{class:{type:[Boolean,null,String,Object,Array],default:void 0},size:{default:void 0}},setup(s){const a=s;return(c,p)=>(t(),r(e(l),{role:"status","aria-label":"Loading",size:a.size,class:i(e(n)("size-4 animate-spin",a.class))},null,8,["size","class"]))}});export{d as _};
