import{e as a}from"./index-Cc0s9xHj.js";import{d as r,c as t,h as l,ae as n,u as c,b as p}from"./lucide-C_a_D9Y7.js";const d=r({__name:"DialogFooter",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const s=e;return(o,f)=>(p(),t("div",{"data-slot":"dialog-footer",class:n(c(a)("flex flex-col-reverse gap-2 sm:flex-row sm:justify-end",s.class))},[l(o.$slots,"default")],2))}});export{d as _};
