import{P as u}from"./reka-ui-jliV5UPF.js";import{e as n}from"./index-Cc0s9xHj.js";import{c as m}from"./index-DX8SDiTF.js";import{d as r,G as f,u as s,ae as l,H as p,h as o,b as i,c as d}from"./lucide-C_a_D9Y7.js";const _=r({__name:"Item",props:{asChild:{type:Boolean},as:{default:"div"},class:{type:[Boolean,null,String,Object,Array],default:void 0},variant:{default:"default"},size:{default:"default"}},setup(t){const e=t;return(a,c)=>(i(),f(s(u),{"data-slot":"item",as:t.as,"as-child":t.asChild,class:l(s(n)(s(g)({variant:t.variant,size:t.size}),e.class))},{default:p(()=>[o(a.$slots,"default")]),_:3},8,["as","as-child","class"]))}}),y=r({__name:"ItemContent",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(t){const e=t;return(a,c)=>(i(),d("div",{"data-slot":"item-content",class:l(s(n)("flex flex-1 flex-col gap-1 [&+[data-slot=item-content]]:flex-none",e.class))},[o(a.$slots,"default")],2))}}),B=r({__name:"ItemTitle",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(t){const e=t;return(a,c)=>(i(),d("div",{"data-slot":"item-title",class:l(s(n)("flex w-fit items-center gap-2 text-sm leading-snug font-medium",e.class))},[o(a.$slots,"default")],2))}}),g=m("group/item flex items-center border border-transparent text-sm rounded-md transition-colors [a]:hover:bg-accent/50 [a]:transition-colors duration-100 flex-wrap outline-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px]",{variants:{variant:{default:"bg-transparent",outline:"border-border",muted:"bg-muted/50"},size:{default:"p-4 gap-4 ",sm:"py-3 px-4 gap-2.5"}},defaultVariants:{variant:"default",size:"default"}});export{_,y as a,B as b};
