import{e as p}from"./index-Cc0s9xHj.js";import{A as i,t as d,v as m}from"./reka-ui-jliV5UPF.js";import{d as l,G as o,u as s,ae as _,H as c,h as n,b as u,D as f}from"./lucide-C_a_D9Y7.js";import{l as v}from"./vueuse-Blk5jQ0T.js";const k=l({__name:"Avatar",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e;return(t,r)=>(u(),o(s(i),{"data-slot":"avatar",class:_(s(p)("relative flex size-8 shrink-0 overflow-hidden rounded-full",a.class))},{default:c(()=>[n(t.$slots,"default")]),_:3},8,["class"]))}}),B=l({__name:"AvatarFallback",props:{delayMs:{},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e,t=v(a,"class");return(r,g)=>(u(),o(s(d),f({"data-slot":"avatar-fallback"},s(t),{class:s(p)("bg-muted flex size-full items-center justify-center rounded-full",a.class)}),{default:c(()=>[n(r.$slots,"default")]),_:3},16,["class"]))}}),C=l({__name:"AvatarImage",props:{src:{},referrerPolicy:{},crossOrigin:{},asChild:{type:Boolean},as:{}},setup(e){const a=e;return(t,r)=>(u(),o(s(m),f({"data-slot":"avatar-image"},a,{class:"aspect-square size-full"}),{default:c(()=>[n(t.$slots,"default")]),_:3},16))}});export{C as _,B as a,k as b};
