.rows-loading[data-v-f1992fbd]{margin:20px 0}.overview-row[data-v-f1992fbd]{margin-top:10px}.overview-container[data-v-f1992fbd]{padding:0 16px 16px}.navigate-icon[data-v-f1992fbd]{margin-left:6px;cursor:pointer;opacity:.7;vertical-align:middle}.navigate-icon[data-v-f1992fbd]:hover{opacity:1}
