import{w as b,x as m,y as _,z as h,B as S}from"./reka-ui-jliV5UPF.js";import{e as n}from"./index-Cc0s9xHj.js";import{d as c,G as i,u as e,D as d,H as t,J as l,b as u,h as v}from"./lucide-C_a_D9Y7.js";import{l as f}from"./vueuse-Blk5jQ0T.js";const x=c({__name:"ScrollBar",props:{orientation:{default:"vertical"},forceMount:{type:Boolean},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array],default:void 0}},setup(a){const r=a,o=f(r,"class");return(s,p)=>(u(),i(e(b),d({"data-slot":"scroll-area-scrollbar"},e(o),{class:e(n)("flex touch-none p-px transition-colors select-none",a.orientation==="vertical"&&"h-full w-2.5 border-l border-l-transparent",a.orientation==="horizontal"&&"h-2.5 flex-col border-t border-t-transparent",r.class)}),{default:t(()=>[l(e(m),{"data-slot":"scroll-area-thumb",class:"bg-border relative flex-1 rounded-full"})]),_:1},16,["class"]))}}),w=c({__name:"ScrollArea",props:{type:{},dir:{},scrollHideDelay:{},asChild:{type:Boolean},as:{},class:{type:[Boolean,null,String,Object,Array]}},setup(a){const r=a,o=f(r,"class");return(s,p)=>(u(),i(e(_),d({"data-slot":"scroll-area"},e(o),{class:e(n)("relative",r.class)}),{default:t(()=>[l(e(h),{"data-slot":"scroll-area-viewport",class:"focus-visible:ring-ring/50 size-full rounded-[inherit] transition-[color,box-shadow] outline-none focus-visible:ring-[3px] focus-visible:outline-1"},{default:t(()=>[v(s.$slots,"default")]),_:3}),l(x),l(e(S))]),_:3},16,["class"]))}});export{w as _};
