import{C as z}from"./Container-C8q3OdIF.js";import{_ as L}from"./ProviderIcon.vue_vue_type_style_index_0_lang-7ardqVNw.js";import{a as i,i as M,_ as S}from"./index-Cc0s9xHj.js";import{u as B}from"./vue-router-lrCq0UAu.js";import{b as D,c as _,Q as f,R as C,d as l,X as k,a as N}from"./vuetify-CvGbteJu.js";import{d as T,o as E,r as F,G as r,H as s,J as n,c as v,O as y,a2 as d,a4 as m,K as R,g as A,F as h,u as x,_ as G,b as a}from"./lucide-C_a_D9Y7.js";import{u as H}from"./vue-i18n-COI_JhGQ.js";import"./index-kQIztB-E.js";import"./qrcode-DICVlH4J.js";import"./marked-D9eDbhZJ.js";import"./color-CqFg8eif.js";import"./vueuse-Blk5jQ0T.js";/* empty css            */import"./swiper-UowLVX5q.js";const J=T({__name:"SystemConfig",setup(K){const u=B(),{t:c}=H(),p=F([]),V=[{domain:"logging",name:"settings.system_logging",description:"settings.system_logging_description",icon:"mdi-text-box-search",route:"/settings/serverlogs"},{domain:"tasks",name:"background_tasks.title",description:"background_tasks.description",icon:"mdi-playlist-play",route:"/settings/tasks"},{domain:"genre_management",name:"settings.genre_management",description:"settings.genre_management_description",icon:M,route:"/settings/genremanagement"}],I=A(()=>[...p.value].sort((e,o)=>i.providerManifests[e.domain].name.localeCompare(i.providerManifests[o.domain].name))),$=e=>{const o=c(`settings.core_module.${e.domain}.name`);return o!==`settings.core_module.${e.domain}.name`?o:i.providerManifests[e.domain].name},b=e=>{const o=c(`settings.core_module.${e.domain}.description`);return o!==`settings.core_module.${e.domain}.description`?o:i.providerManifests[e.domain].description},g=function(e){"route"in e&&e.route?u.push(e.route):u.push(`/settings/editcore/${e.domain}`)};return E(async()=>{p.value=await i.getCoreConfigs()}),(e,o)=>(a(),r(z,{variant:"comfortable",class:"settings-overview"},{default:s(()=>[n(N,{class:"settings-main-card"},{default:s(()=>[n(D,{class:"settings-list"},{default:s(()=>[(a(!0),v(h,null,y(I.value,t=>(a(),r(_,{key:t.domain,ripple:!0,class:"settings-list-item",onClick:w=>g(t)},{prepend:s(()=>[n(k,{color:"blue",size:"48"},{default:s(()=>[n(L,{domain:t.domain,size:24,color:"white"},null,8,["domain"])]),_:2},1024)]),append:s(()=>[t.last_error?(a(),r(l,{key:0,color:"red",icon:"mdi-alert-circle",class:"mr-2",title:t.last_error},null,8,["title"])):R("",!0),n(l,{icon:"mdi-chevron-right"})]),default:s(()=>[n(f,{class:"text-h6"},{default:s(()=>[d(m($(t)),1)]),_:2},1024),n(C,null,{default:s(()=>[d(m(b(t)),1)]),_:2},1024)]),_:2},1032,["onClick"]))),128)),(a(),v(h,null,y(V,t=>n(_,{key:t.domain,ripple:!0,class:"settings-list-item",onClick:w=>g(t)},{prepend:s(()=>[n(k,{color:"purple",size:"48"},{default:s(()=>[typeof t.icon!="string"?(a(),r(G(t.icon),{key:0,class:"size-6 text-white"})):(a(),r(l,{key:1,icon:t.icon,size:"24",color:"white"},null,8,["icon"]))]),_:2},1024)]),append:s(()=>[n(l,{icon:"mdi-chevron-right"})]),default:s(()=>[n(f,{class:"text-h6"},{default:s(()=>[d(m(x(c)(t.name)),1)]),_:2},1024),n(C,null,{default:s(()=>[d(m(x(c)(t.description)),1)]),_:2},1024)]),_:2},1032,["onClick"])),64))]),_:1})]),_:1})]),_:1}))}}),oe=S(J,[["__scopeId","data-v-6e55ef12"]]);export{oe as default};
