import{e as u}from"./index-Cc0s9xHj.js";import{u as p,$ as m,a0 as b}from"./reka-ui-jliV5UPF.js";import{d as f,G as h,u as e,D as g,H as r,J as s,h as k,aI as v,L as x,M as _,b as y}from"./lucide-C_a_D9Y7.js";import{l as C}from"./vueuse-Blk5jQ0T.js";const I=f({__name:"Checkbox",props:{defaultValue:{},modelValue:{},disabled:{type:Boolean},value:{},id:{},trueValue:{},falseValue:{},asChild:{type:Boolean},as:{},name:{},required:{type:Boolean},class:{type:[Boolean,null,String,Object,Array]}},emits:["update:modelValue"],setup(t,{emit:o}){const a=t,i=o,d=C(a,"class"),n=p(d,i);return(c,w)=>(y(),h(e(m),g({"data-slot":"checkbox"},e(n),{class:e(u)("peer border-input data-[state=checked]:bg-primary data-[state=checked]:text-primary-foreground data-[state=checked]:border-primary focus-visible:border-ring focus-visible:ring-ring/50 aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive size-4 shrink-0 rounded-[4px] border shadow-xs transition-shadow outline-none focus-visible:ring-[3px] disabled:cursor-not-allowed disabled:opacity-50",a.class)}),{default:r(l=>[s(e(b),{"data-slot":"checkbox-indicator",class:"grid place-content-center text-current transition-none"},{default:r(()=>[k(c.$slots,"default",x(_(l)),()=>[s(e(v),{class:"size-3.5"})])]),_:2},1024)]),_:3},16,["class"]))}});export{I as _};
