import{e as s}from"./index-Cc0s9xHj.js";import{P as o}from"./reka-ui-jliV5UPF.js";import{c as n}from"./index-DX8SDiTF.js";import{d,G as c,u as e,D as l,H as v,h as u,b as g}from"./lucide-C_a_D9Y7.js";import{l as f}from"./vueuse-Blk5jQ0T.js";const k=d({__name:"Badge",props:{asChild:{type:Boolean},as:{},variant:{},class:{type:[Boolean,null,String,Object,Array]}},setup(r){const t=r,a=f(t,"class");return(i,b)=>(g(),c(e(o),l({"data-slot":"badge",class:e(s)(e(p)({variant:r.variant}),t.class)},e(a)),{default:v(()=>[u(i.$slots,"default")]),_:3},16,["class"]))}}),p=n("inline-flex items-center justify-center rounded-full border px-2 py-0.5 text-xs font-medium w-fit whitespace-nowrap shrink-0 [&>svg]:size-3 gap-1 [&>svg]:pointer-events-none focus-visible:border-ring focus-visible:ring-ring/50 focus-visible:ring-[3px] aria-invalid:ring-destructive/20 dark:aria-invalid:ring-destructive/40 aria-invalid:border-destructive transition-[color,box-shadow] overflow-hidden",{variants:{variant:{default:"border-transparent bg-primary text-primary-foreground [a&]:hover:bg-primary/90",secondary:"border-transparent bg-secondary text-secondary-foreground [a&]:hover:bg-secondary/90",destructive:"border-transparent bg-destructive text-white [a&]:hover:bg-destructive/90 focus-visible:ring-destructive/20 dark:focus-visible:ring-destructive/40 dark:bg-destructive/60",outline:"text-foreground [a&]:hover:bg-accent [a&]:hover:text-accent-foreground"}},defaultVariants:{variant:"default"}});export{k as _};
