.header.v-toolbar[data-v-d8721ced] .v-toolbar-title{margin-inline-start:0px;font-size:large;font-weight:700}.header.v-toolbar[data-v-d8721ced]{padding-inline-start:4px}.widget-row[data-v-d8721ced]{margin-bottom:10px;margin-left:0;margin-right:0;padding-left:0}@media(max-width:575px){.widget-row[data-v-d8721ced]{margin-bottom:4px}}.disabled[data-v-d8721ced]{opacity:.2}.enabled[data-v-d8721ced]{opacity:1}.widget-row-panel-item[data-v-d8721ced]{margin-bottom:10px}.v-slide-group__prev[data-v-d8721ced]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-d8721ced]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-d8721ced]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-d8721ced]{visibility:hidden}[data-v-d8721ced] .swiper-slide{width:auto;flex-shrink:0}.v-progress-circular[data-v-dc4e9fa9]{display:block;margin-inline:auto}.editButton[data-v-dc4e9fa9]{float:right;margin-bottom:10px}.avatar-trigger[data-v-dc4e9fa9]{cursor:pointer;margin-right:8px}.avatar-trigger[data-v-dc4e9fa9]:hover{opacity:.9}.user-avatar[data-v-dc4e9fa9]{border:1px solid rgba(var(--v-border-color),var(--v-border-opacity))}.provider-warning-content[data-v-dc4e9fa9]{display:flex;align-items:center;justify-content:space-between;gap:16px;flex-wrap:wrap}.user-header-section[data-v-dc4e9fa9]{display:flex;align-items:center;gap:12px;padding:4px;background-color:hsl(var(--muted) / .3);border-radius:calc(var(--radius) - 2px);margin-bottom:4px}@media(max-width:600px){.provider-warning-content[data-v-dc4e9fa9]{flex-direction:column;align-items:stretch}}@media(max-width:575px){[data-v-dc4e9fa9] .container-comfortable{padding:12px}}
