.button[data-v-f097a0e8]:focus-visible{outline:2px solid var(--v-theme-primary);outline-offset:2px}@media(prefers-contrast:high){.button[data-v-f097a0e8]{border:1px solid currentColor}}@media(prefers-reduced-motion:reduce){.button[data-v-f097a0e8]{transition:none}}.button--responsive[data-v-f097a0e8]{min-height:48px;min-width:48px}.button--icon[data-v-f097a0e8]{min-height:40px;min-width:40px}.button--icon[data-v-f097a0e8] .v-ripple__container{border-radius:50%!important;transform:scale(.7)!important}.button--icon[data-v-f097a0e8] .v-ripple__animation{border-radius:50%!important}.button--nav[data-v-f097a0e8]{border-radius:0}
