import{e as t}from"./index-Cc0s9xHj.js";import{d as n,c as o,ae as r,u as c,h as l,b as p}from"./lucide-C_a_D9Y7.js";const u=n({__name:"CardContent",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(e){const a=e;return(s,m)=>(p(),o("div",{"data-slot":"card-content",class:r(c(t)("px-6",a.class))},[l(s.$slots,"default")],2))}});export{u as _};
