import{d as o,c as t,J as n,aw as r,b as a}from"./lucide-C_a_D9Y7.js";const u=o({__name:"PartyGuestLayout",setup(s){return(c,_)=>{const e=r("router-view");return a(),t("div",null,[n(e)])}}});export{u as default};
